@@ -2,19 +2,20 @@
 # -*- coding: utf-8 -*-
 
 import os
+import sys
 import json
 import gettext
 from functools import wraps
+from jinja2 import BaseLoader
 from jinja2 import Environment
+from jinja2 import ChoiceLoader
 from jinja2 import FileSystemLoader
 from jinja2 import TemplateNotFound
-from jinja2 import BaseLoader
-from jinja2 import ChoiceLoader
-from config import Config
 from bottle import request, response
-from errors import BaseError, ValidationError, ConnectionError
-
-from logger import Log
+from .logger import Log
+from .config import Config
+from .session import Session
+from .errors import BaseError, ValidationError, ConnectionError
 
 
 class DecanterLoader(BaseLoader):
@@ -115,7 +116,7 @@ class JsonPlugin(object):
             try:
                 data = callback(*args, **kwargs)
             # catch validation errors from the controller
-            except (BaseError, ValidationError, ConnectionError), e:
+            except (BaseError, ValidationError, ConnectionError) as e:
                 # create a standardized error object
                 data = {
                     'opstat': 'error'
@@ -153,3 +154,36 @@ class JsonPlugin(object):
 
     def close(self):
         pass
+
+
+class SessionPlugin(object):
+    __state = {}
+    name = 'session'
+    api = 2
+
+    def __init__(self):
+        """ Borg Pattern """
+        self.__dict__ = self.__state
+        if 'ses' not in self.__dict__:
+            config = Config.get_instance()
+            self.name = ''.join([config.session.get('type').title(), 'Session'])
+            if 'decanter.lib.session' not in sys.modules:
+                self.module = __import__('lib.session', fromlist=[self.name])
+            else:
+                self.module = sys.modules['decanter.lib.session']
+
+    def apply(self, callback, route):
+        @wraps(callback)
+        def wrapper(*args, **kwargs):
+            ses = Session(getattr(self.module, self.name)())
+            ses.read()
+            data = callback(*args, **kwargs)
+            ses.write()
+            return data
+        return wrapper
+
+    def setup(self, app):
+        pass
+
+    def close(self):
+        pass
